/* File ctype.h supplied with Escher C Verifier.
 * Use this file only if you are using the eCv preprocessor.
 * If you wish to use a compiler to preprocess C/C++ source instead, then
 *  you should use the standard include files supplied with that compiler.
 */

#if !defined(__ecv_ctype_h_included__)
#define __ecv_ctype_h_included__

#pragma ECV noverify

#if defined(__ECV__)

int isalnum(int);
int isalpha(int);

# if (defined(__STDC_VERSION__) && (__STDC_VERSION__ >= 199901L)) || (defined(__cplusplus) && (__cplusplus >= 201103L))
int isblank(int);
# endif

int iscntrl(int);
int isdigit(int);
int isgraph(int);
int islower(int);
int isprint(int);
int ispunct(int);
int isspace(int);
int isupper(int);
int isxdigit(int);

int tolower(int);
int toupper(int);

#else
# error "Missing macro definitions! Use this include file only when running Escher C verifier."
#endif

#endif

/* End */
